@@ -42,8 +42,8 @@ class Player(PlayerBase):
 		if not "artist" in data.keys() or not "name" in data.keys() or not "album" in data.keys():
 			return
 		
-		return {"artist": unicode(data["artist"]), "title": unicode(data["name"]), "album": unicode(data["album"]), 
-				"uri": unicode(data["URI"])}
+		return {"artist": utf8(data["artist"]), "title": utf8(data["name"]), "album": utf8(data["album"]), 
+				"uri": utf8(data["URI"])}
 	
 	def play_pause(self):
 		try:
